/**
 * This file is part of IoTool Arduino Library.
 * 
 * IoTool Arduino Library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * IoTool Arduino Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with IoTool Arduino Library. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * IoTool Arduino Library demo Sketch.
 *
 * This Sketch creates action that toggles LED on pin 13 on most Arduino boards.
 * Before action will be visible in IoTool snyc is required. Navigate to IoTool
 * Arduino Service preferences and click sync. Make sure that correct MAC is set
 * before attemping to sync.
 */

#include <IoTool.h>

// Create IoTool object
IoTool ioTool;
// Create IoTool action
IoToolAction myAction("led", "Toggle LED");

void myActionHandler() {
  digitalWrite(13, !digitalRead(13));
}

void setup() {
  // Set pin 13 as output
  pinMode(13, OUTPUT);
  
  // IoTool Library sends data to the service on Android phone using Bluetooth
  // connection. Connect your module to pins 0 (RX) and 1 (TX) on your Arduino.
  // Make sure that Bluetooth module uses exact same baud rate as specified here.
  Serial.begin(57600);
  // Set serial connection on IoTool object, IoTool will use this connection to
  // send and receive data to and from the IoTool Arduino Service.
  ioTool.setSerial(Serial);

  // Set action handler of the IoToolAction object.
  // This function will be executed in IoTool object loop method.
  myAction.setHandler(myActionHandler);

  // Add action to IoTool object
  ioTool.addAction(myAction);
}

void loop() {
  // Execute main loop of the IoTool object. Action will be executed in this loop
  // when IoTool sends action execution command.
  ioTool.loop();
}
